<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Starts a stopped AWS Instance.
 *
 * @package Drupal\aws_cloud\Form\Ec2
 */
class InstanceStartForm extends AwsDeleteUpdateEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    $entity = $this->entity;

    return $this->t('Are you sure you want to start instance: %name?', [
      '%name' => $entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Start');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {

    $entity = $this->entity;

    if (!$this->updateEntitySubmitForm($form_state, $entity)) {
      return;
    }

    $params = [
      'InstanceIds' => [
        $entity->getInstanceId(),
      ],
    ];

    $this->ec2Service->setCloudContext($entity->getCloudContext());
    $result = $this->ec2Service->startInstances($params);

    if (empty($result)) {
      $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
      return;
    }

    if (!empty($result['SendToWorker'])) {
      $this->processOperationStatus($entity, 'started remotely');
      $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
      return;
    }

    try {
      $current_state = $result['StartingInstances'][0]['CurrentState']['Name'];
      $instance = $this->entityTypeManager
        ->getStorage($entity->getEntityTypeId())
        ->load($entity->id());
      $instance->setInstanceState($current_state);
      $instance->save();

      $this->processOperationStatus($instance, 'started');
      $this->clearCacheValues($entity->getCacheTags());
      $this->dispatchSubmitEvent($entity);
    }
    catch (\Exception $e) {
      $this->handleException($e);
    }

    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
  }

}
